==> jc-1.4.0.tar.gz: gnu/java/lang/MainThread.h <==
// public class gnu.java.lang.MainThread

// class file dependencies
// @dep_class d9db5efd62f0f560 gnu_java_lang_MainThread
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_MainThread_H_
#define _JC_gnu_java_lang_MainThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_lang_MainThread$sub_refs	_jc_gnu_java_lang_MainThread$sub_refs;
typedef struct _jc_gnu_java_lang_MainThread$sub_nonrefs	_jc_gnu_java_lang_MainThread$sub_nonrefs;
typedef struct _jc_gnu_java_lang_MainThread$refs	_jc_gnu_java_lang_MainThread$refs;
typedef struct _jc_gnu_java_lang_MainThread$nonrefs	_jc_gnu_java_lang_MainThread$nonrefs;
typedef struct _jc_gnu_java_lang_MainThread$object	_jc_gnu_java_lang_MainThread$object;

typedef const struct _jc_gnu_java_lang_MainThread$vmethods	_jc_gnu_java_lang_MainThread$vmethods;
typedef const struct _jc_gnu_java_lang_MainThread$vtable	_jc_gnu_java_lang_MainThread$vtable;
typedef const struct _jc_gnu_java_lang_MainThread$vtype	_jc_gnu_java_lang_MainThread$vtype;

// Constructors
extern void _jc_gnu_java_lang_MainThread$method$_init$c23bfa1ec2b2f494(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern void _jc_gnu_java_lang_MainThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_lang_MainThread$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_java_lang_MainThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *);
};

// Vtable
struct _jc_gnu_java_lang_MainThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_MainThread$vmethods	gnu_java_lang_MainThread;
};

// Vtype
struct _jc_gnu_java_lang_MainThread$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_MainThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_MainThread$sub_refs {
	_jc_object_array	*args;
	struct _jc_java_lang_reflect_Method$object	*mainMethod;
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_MainThread$refs {
    _jc_gnu_java_lang_MainThread$sub_refs	gnu_java_lang_MainThread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_MainThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_MainThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_MainThread$sub_nonrefs	gnu_java_lang_MainThread;
};

// Object instance structure
struct _jc_gnu_java_lang_MainThread$object {
	_jc_gnu_java_lang_MainThread$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_MainThread$vtype	*vtype;
	_jc_gnu_java_lang_MainThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_MainThread$vtype _jc_gnu_java_lang_MainThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_MainThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_MainThread$class_object;

#endif	/* _JC_gnu_java_lang_MainThread_H_ */

==> jc-1.4.6.tar.gz: gnu/java/lang/MainThread.h <==
// public class gnu.java.lang.MainThread

// class file dependencies
// @dep_class 2130c3597e1eaedc gnu_java_lang_MainThread
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_MainThread_H_
#define _JC_gnu_java_lang_MainThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_lang_MainThread$sub_refs	_jc_gnu_java_lang_MainThread$sub_refs;
typedef struct _jc_gnu_java_lang_MainThread$sub_nonrefs	_jc_gnu_java_lang_MainThread$sub_nonrefs;
typedef struct _jc_gnu_java_lang_MainThread$refs	_jc_gnu_java_lang_MainThread$refs;
typedef struct _jc_gnu_java_lang_MainThread$nonrefs	_jc_gnu_java_lang_MainThread$nonrefs;
typedef struct _jc_gnu_java_lang_MainThread$object	_jc_gnu_java_lang_MainThread$object;

typedef const struct _jc_gnu_java_lang_MainThread$vmethods	_jc_gnu_java_lang_MainThread$vmethods;
typedef const struct _jc_gnu_java_lang_MainThread$vtable	_jc_gnu_java_lang_MainThread$vtable;
typedef const struct _jc_gnu_java_lang_MainThread$vtype	_jc_gnu_java_lang_MainThread$vtype;

// Constructors
extern void _jc_gnu_java_lang_MainThread$method$_init$c23bfa1ec2b2f494(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_lang_MainThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_lang_MainThread$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_java_lang_MainThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_lang_MainThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_lang_MainThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_MainThread$vmethods	gnu_java_lang_MainThread;
};

// Vtype
struct _jc_gnu_java_lang_MainThread$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_MainThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_MainThread$sub_refs {
	_jc_object_array	*args;
	struct _jc_java_lang_reflect_Method$object	*mainMethod;
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_MainThread$refs {
    _jc_gnu_java_lang_MainThread$sub_refs	gnu_java_lang_MainThread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_MainThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_MainThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_MainThread$sub_nonrefs	gnu_java_lang_MainThread;
};

// Object instance structure
struct _jc_gnu_java_lang_MainThread$object {
	_jc_gnu_java_lang_MainThread$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_MainThread$vtype	*vtype;
	_jc_gnu_java_lang_MainThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_MainThread$vtype _jc_gnu_java_lang_MainThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_MainThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_MainThread$class_object;

#endif	/* _JC_gnu_java_lang_MainThread_H_ */
